@@ -57,6 +57,7 @@ namespace Banshee.Sources
         public event EventHandler Updated;
         public event TrackEventHandler TrackAdded;
         public event TrackEventHandler TrackRemoved;
+        public event EventHandler ViewChanged;
         
         protected Source(string name, int order)
         {
@@ -72,6 +73,10 @@ namespace Banshee.Sources
         public virtual void Activate()
         {
         }
+
+        public virtual void Deactivate()
+        {
+        }
         
         protected virtual void OnDispose()
         {
@@ -160,6 +165,14 @@ namespace Banshee.Sources
             }
         }
         
+        protected virtual void OnViewChanged()
+        {
+            EventHandler handler = ViewChanged;
+            if(handler != null) {
+                handler(this, new EventArgs());
+            }
+        }
+        
         public virtual int Count {
             get {
                 return -1;
@@ -176,9 +189,11 @@ namespace Banshee.Sources
             }
         }
         
+        private static readonly ArrayList empty_track_list = new ArrayList();
+        
         public virtual IEnumerable Tracks {
             get {
-                return new ArrayList();
+                return empty_track_list;
             }
         }
         
@@ -188,6 +203,24 @@ namespace Banshee.Sources
             }
         }
         
+        public virtual Gtk.Widget ViewWidget {
+            get {
+                return null;
+            }
+        }
+        
+        public virtual bool ShowPlaylistHeader {
+            get {
+                return true;
+            }
+        }
+        
+        public virtual bool HandlesSearch {
+            get {
+                return false;
+            }
+        }
+        
         public int Order {
             get {
                 return order;
