@@ -95,7 +95,7 @@ namespace Banshee.Base
         
         public static int ExecProcess(string command, string args)
         {
-            Process process = Process.Start(command, args);
+            Process process = Process.Start(command, args == null ? "" : args);
             process.WaitForExit();
             return process.ExitCode;
         }
@@ -131,6 +131,17 @@ namespace Banshee.Base
             Gdk.Colormap.System.AllocColor(ref color, true, true);
             return color;
         }
+        
+        [DllImport("libc")]
+        private static extern int prctl(int option, byte [] arg2, ulong arg3 , ulong arg4, ulong arg5);
+        
+        public static void SetProcessName(string name)
+        {
+            if(prctl(15 /* PR_SET_NAME */, Encoding.ASCII.GetBytes(name), 0, 0, 0) != 0) {
+                throw new ApplicationException("Error setting process name: " + 
+                    Mono.Unix.Native.Stdlib.GetLastError());
+            }
+        }
     }
     
     public static class ReflectionUtil
@@ -228,6 +239,7 @@ namespace Banshee.Base
         public static Thread Spawn(ThreadStart threadedMethod, bool autoStart)
         {
             Thread thread = new Thread(threadedMethod);
+            thread.IsBackground = true;
             if(autoStart) {
                 thread.Start();
             }
@@ -316,7 +328,7 @@ namespace Banshee.Base
     
     public static class PathUtil
     {
-        private static char[] CharsToQuote = { ';', '?', ':', '@', '&', '=', '$', ',', '#' };
+        private static char[] CharsToQuote = { ';', '?', ':', '@', '&', '=', '$', ',', '#', '%' };
        
         public static Uri PathToFileUri(string path)
         {
