@@ -58,6 +58,10 @@ namespace Banshee
         
         private static void Startup(string [] args)
         {
+            try {
+                Utilities.SetProcessName("banshee");
+            } catch {}
+            
             Gtk.Application.Init();
         
             Globals.ArgumentQueue = new ArgumentQueue(new ArgumentLayout [] {
@@ -76,6 +80,7 @@ namespace Banshee
                 new ArgumentLayout("query-duration", "Get duration of current playing song in seconds"),
                 new ArgumentLayout("query-position", "Get position of current playing song in seconds"),
                 new ArgumentLayout("query-uri",      "Get URI of current playing song"),
+                new ArgumentLayout("query-cover-uri","Get URI of the album cover of current playing song"),
                 new ArgumentLayout("query-status",   "Get player status (-1: Not loaded, 0: Paused, 1: Playing)"),
                 new ArgumentLayout("hide-field",     "Do not display field name for --query-* results"),
                 new ArgumentLayout("help",           "List available command line arguments"),
@@ -100,7 +105,7 @@ namespace Banshee
             try {
                 return RemotePlayer.FindInstance();
             } catch {
-                Process current_process = Process.GetCurrentProcess();
+                /*Process current_process = Process.GetCurrentProcess();
                 foreach(Process process in Process.GetProcesses()) {
                     if(process.ProcessName == current_process.ProcessName && process.Id != current_process.Id) {
                         Console.WriteLine(Catalog.GetString(""));
@@ -109,7 +114,7 @@ namespace Banshee
                             "Banshee could not connect to your D-Bus Session Bus."));
                         System.Environment.Exit(1);
                     }
-                }
+                }*/
 
                 return null;
             }
@@ -182,6 +187,10 @@ namespace Banshee
                     PrintQueryResult("Uri", remote_player.GetPlayingUri());
                     present = false;
                     break;
+                case "query-cover-uri":
+                    PrintQueryResult("CoverUri", remote_player.GetPlayingCoverUri());
+                    present = false;
+                    break;
                 case "query-status":
                     PrintQueryResult("Status", remote_player.GetPlayingStatus());
                     present = false;
