@@ -86,8 +86,6 @@ namespace Banshee
         private ActionButton rip_button;
         
         private ActionButton sync_dap_button;
-        private EventBox syncing_container;
-        private Gtk.Image dap_syncing_image = new Gtk.Image();
         [Widget] private ProgressBar dapDiskUsageBar;
         
         private HighlightMessageArea audiocd_statusbar;
@@ -168,23 +166,7 @@ namespace Banshee
             
             InitialLoadTimeout();
             WindowPlayer.Show();
-            
-            /*try {
-                if((bool)Globals.Configuration.Get(GConfKeys.EnableSpecialKeys)) {
-                    special_keys = new SpecialKeys();
-                    special_keys.Delay = new TimeSpan(350 * TimeSpan.TicksPerMillisecond);
-                    special_keys.RegisterHandler(OnSpecialKeysPressed, 
-                        SpecialKey.AudioPlay,
-                        SpecialKey.AudioPrev,
-                        SpecialKey.AudioNext
-                    );
-                }
-            } catch(GConf.NoSuchKeyException) {
-            } catch(Exception e) {
-                special_keys = null;
-                LogCore.Instance.PushWarning(Catalog.GetString("Could not setup special keys"), e.Message, false);
-            }*/
-            
+
             // Bind available methods to actions defined in ActionManager
             Globals.ActionManager.DapActions.Visible = false;
             Globals.ActionManager.AudioCdActions.Visible = false;
@@ -220,7 +202,6 @@ namespace Banshee
             
             foreach(DapDevice device in DapCore.Devices) {
                  device.PropertiesChanged += OnDapPropertiesChanged;
-                 device.SaveStarted += OnDapSaveStarted;
                  device.SaveFinished += OnDapSaveFinished;
             }
             
@@ -385,6 +366,7 @@ namespace Banshee
             sourceView.Sensitive = false;
             SourceManager.ActiveSourceChanged += OnSourceManagerActiveSourceChanged;
             SourceManager.SourceUpdated += OnSourceManagerSourceUpdated;
+            SourceManager.SourceViewChanged += OnSourceManagerSourceViewChanged;
             SourceManager.SourceTrackAdded += OnSourceTrackAdded;
             SourceManager.SourceTrackRemoved += OnSourceTrackRemoved;
             
@@ -400,6 +382,7 @@ namespace Banshee
             // Playlist View
             playlistModel = new PlaylistModel();
             playlistView = new PlaylistView(playlistModel);
+            InterfaceElements.PlaylistView = playlistView;
             ((Gtk.ScrolledWindow)gxml["LibraryContainer"]).Add(playlistView);
             playlistView.Show();
             playlistModel.Updated += OnPlaylistUpdated;
@@ -441,13 +424,16 @@ namespace Banshee
             
             searchEntry = new SearchEntry(fields);
             searchEntry.EnterPress += delegate(object o, EventArgs args) {
-                if(playlistView.Selection.CountSelectedRows() == 0 && playlistModel.Count() > 0) {
-                    playlistView.Selection.SelectPath(new TreePath(new int [] { 0 }));
+                if(!SourceManager.ActiveSource.HandlesSearch) {
+                    if(playlistView.Selection.CountSelectedRows() == 0 && playlistModel.Count() > 0) {
+                        playlistView.Selection.SelectPath(new TreePath(new int [] { 0 }));
+                    }
+                    playlistView.HasFocus = true;
                 }
-                playlistView.HasFocus = true;
             };
             searchEntry.Changed += OnSimpleSearch;
             searchEntry.Show();
+            InterfaceElements.SearchEntry = searchEntry;
             ((HBox)gxml["PlaylistHeaderBox"]).PackStart(searchEntry, false, false, 0);
                 
             gxml["SearchLabel"].Sensitive = false;
@@ -643,7 +629,8 @@ namespace Banshee
                 SourceManager.SetActiveSource(LibrarySource.Instance);
             }
 
-            if(Globals.ArgumentQueue.Contains("play")) {
+            if(Globals.ArgumentQueue.Contains("play") || 
+                (Globals.ArgumentQueue.Contains("play-enqueued") && LocalQueueSource.Instance.Count > 0)) {
                 GLib.Timeout.Add(1500, delegate {
                     PlayPause();
                     return false;
@@ -797,7 +784,7 @@ namespace Banshee
                 case Gdk.Key.S:
                 case Gdk.Key.s:
                 case Gdk.Key.F3:
-                    if(!searchEntry.HasFocus) {
+                    if(!searchEntry.HasFocus && !sourceView.EditingRow) {
                         searchEntry.Focus();
                         handled = true;
                     }
@@ -911,22 +898,7 @@ namespace Banshee
             playlistModel.Advance();
             playlistView.UpdateView();
         }
-        
-        private void OnSpecialKeysPressed(object o, SpecialKey key)
-        {
-            switch(key) {
-                case SpecialKey.AudioPlay:
-                    PlayPause();
-                    break;
-                case SpecialKey.AudioNext:
-                    Next();
-                    break;
-                case SpecialKey.AudioPrev:
-                    Previous();
-                    break;
-            }
-        }
-        
+         
         private void OnVolumeScaleChanged(int volume)
         {
             PlayerEngineCore.ActivePlayer.Volume = (ushort)volume;
@@ -1106,6 +1078,59 @@ namespace Banshee
             }
         }
         
+        private void OnSourceManagerSourceViewChanged(SourceEventArgs args)
+        {
+            if(args.Source == SourceManager.ActiveSource) {
+                UpdateSourceView();
+            }
+        }
+        
+        private void UpdateSourceView()
+        {
+            if(SourceManager.ActiveSource.ViewWidget != null) {
+                ShowSourceWidget();
+            } else {
+                ShowPlaylistView();
+            }
+        }
+        
+        private void ShowPlaylistView()
+        {
+            Alignment alignment = gxml["LibraryAlignment"] as Alignment;
+            ScrolledWindow playlist_container = gxml["LibraryContainer"] as ScrolledWindow;
+            
+            if(alignment.Child == playlist_container) {
+                return;
+            } else if(alignment.Child != null) {
+                alignment.Remove(alignment.Child);
+            }
+            
+            alignment.Add(playlist_container);
+            alignment.ShowAll();
+            
+            gxml["PlaylistHeaderBox"].Show();
+        }
+        
+        private void ShowSourceWidget()
+        {
+            Alignment alignment = gxml["LibraryAlignment"] as Alignment;
+            
+            if(alignment.Child == SourceManager.ActiveSource.ViewWidget) {
+                return;
+            }
+            
+            if(SourceManager.ActiveSource.ViewWidget == null) {
+                ShowPlaylistView();
+                return;
+            } 
+            
+            alignment.Remove(alignment.Child);
+            alignment.Add(SourceManager.ActiveSource.ViewWidget);
+            alignment.ShowAll();
+            
+            gxml["PlaylistHeaderBox"].Visible = SourceManager.ActiveSource.ShowPlaylistHeader;
+        }
+        
         private void OnSourceTrackAdded(object o, TrackEventArgs args)
         {
             if(SourceManager.ActiveSource == o) {
@@ -1214,7 +1239,7 @@ namespace Banshee
                 return;
             }
 
-            searchEntry.CancelSearch(false);
+            searchEntry.CancelSearch();
             audiocd_statusbar.Visible = false;
             
             if(source is DapSource) {
@@ -1236,23 +1261,13 @@ namespace Banshee
             }
             
             gxml["SearchLabel"].Sensitive = !(source is AudioCdSource);
-            if(source is DapSource && ((source as DapSource).IsSyncing)) {
-                gxml["SearchLabel"].Sensitive = false;
-            }
-            
             searchEntry.Sensitive = gxml["SearchLabel"].Sensitive;
             playlistView.RipColumn.Visible = source is AudioCdSource;
             playlistView.RatingColumn.Visible = !(source is AudioCdSource);
             playlistView.PlaysColumn.Visible = playlistView.RatingColumn.Visible;
             playlistView.LastPlayedColumn.Visible = playlistView.RatingColumn.Visible;
                 
-            if(!(source is DapSource)) {
-                ShowPlaylistView();
-            } else if((source as DapSource).IsSyncing) {
-                ShowSyncingView();
-            } else {
-                ShowPlaylistView();
-            }
+            UpdateSourceView();
                 
             OnPlaylistViewSelectionChanged(playlistView.Selection, new EventArgs());
         }
@@ -1291,7 +1306,6 @@ namespace Banshee
         private void OnDapCoreDeviceAdded(object o, DapEventArgs args)
         {
             args.Dap.PropertiesChanged += OnDapPropertiesChanged;
-            args.Dap.SaveStarted += OnDapSaveStarted;
             args.Dap.SaveFinished += OnDapSaveFinished;
         }
         
@@ -1332,26 +1346,10 @@ namespace Banshee
             }
         }
         
-        private void OnDapSaveStarted(object o, EventArgs args)
-        {
-            if(SourceManager.ActiveSource is DapSource
-                && (SourceManager.ActiveSource as DapSource).IsSyncing) {
-                ShowSyncingView();
-                gxml["SearchLabel"].Sensitive = false;
-                searchEntry.Sensitive = false;
-                Globals.ActionManager.DapActions.Sensitive = false;
-                dap_syncing_image.Pixbuf = (SourceManager.ActiveSource as DapSource).Device.GetIcon(128);
-            }
-        }
-        
         private void OnDapSaveFinished(object o, EventArgs args)
         {
             if(SourceManager.ActiveSource is DapSource
                 && !(SourceManager.ActiveSource as DapSource).IsSyncing) {
-                ShowPlaylistView();
-                gxml["SearchLabel"].Sensitive = true;
-                searchEntry.Sensitive = true;
-                Globals.ActionManager.DapActions.Sensitive = true;
                 playlistModel.ReloadSource();
                 UpdateDapDiskUsageBar(SourceManager.ActiveSource as DapSource);
             }
@@ -1360,52 +1358,6 @@ namespace Banshee
             playlistView.QueueDraw();
         }
 
-        private void ShowPlaylistView()
-        {
-            Alignment alignment = gxml["LibraryAlignment"] as Alignment;
-            ScrolledWindow playlist_container = gxml["LibraryContainer"] as ScrolledWindow;
-            
-            if(alignment.Child == playlist_container) {
-                return;
-            } else if(alignment.Child == syncing_container) {
-                alignment.Remove(syncing_container);
-            }
-            
-            alignment.Add(playlist_container);
-            alignment.ShowAll();
-        }
-        
-        private void ShowSyncingView()
-        {
-            Alignment alignment = gxml["LibraryAlignment"] as Alignment;
-            ScrolledWindow playlist_container = gxml["LibraryContainer"] as ScrolledWindow;
-            
-            if(alignment.Child == syncing_container) {
-                return;
-            } else if(alignment.Child == playlist_container) {
-                alignment.Remove(playlist_container);
-            }
-            
-            if(syncing_container == null) {
-                syncing_container = new EventBox();
-                HBox syncing_box = new HBox();
-                syncing_container.Add(syncing_box);
-                syncing_box.Spacing = 20;
-                syncing_box.PackStart(dap_syncing_image, false, false, 0);
-                Label syncing_label = new Label();
-                                                
-                syncing_container.ModifyBg(StateType.Normal, new Color(0, 0, 0));
-                syncing_label.ModifyFg(StateType.Normal, new Color(160, 160, 160));
-            
-                syncing_label.Markup = "<big><b>" + GLib.Markup.EscapeText(
-                    Catalog.GetString("Synchronizing your Device, Please Wait...")) + "</b></big>";
-                syncing_box.PackStart(syncing_label, false, false, 0);
-            }
-            
-            alignment.Add(syncing_container);
-            alignment.ShowAll();
-        }
-
         private void OnPlaylistUpdated(object o, EventArgs args)
         {
             long count = playlistModel.Count();
@@ -1563,6 +1515,10 @@ namespace Banshee
         
         private void OnSimpleSearch(object o, EventArgs args)
         {
+            if(SourceManager.ActiveSource.HandlesSearch) {
+                return;
+            }
+            
             playlistModel.Clear();
             
             if(!searchEntry.IsQueryAvailable) {
@@ -2463,7 +2419,9 @@ namespace Banshee
         
         private void OnAboutAction(object o, EventArgs args)
         {
-            new AboutBox();
+            BansheeAboutDialog about = new BansheeAboutDialog();
+            about.Run();
+            about.Destroy();
         }
     }
 }
