@@ -497,204 +497,6 @@ namespace Banshee
             }
         }
         
-        //QueueDraw();
-        //ScrollToCell(playingPath, null, true, 0.5f, 0.0f);
-
-        /*
-        private void PlayRandomIter()
-        {
-            if(playedUids.Count == Count()) {
-                playedUids.Clear();
-                if(!repeat) {
-                    return;
-                }
-            }
-                
-            while(true) {
-                TreeIter randIter;
-                int randIndex = Core.Instance.Random.Next(0, Count());
-                if(!store.IterNthChild(out randIter, randIndex))
-                    continue;
-                
-                TrackInfo rti = IterTrackInfo(randIter);
-                
-                if(playedUids.IndexOf(rti.Uid) == -1) {
-                    PlayIter(randIter);
-                    return;
-                }
-            }
-        }
-        
-        private TrackInfo PlayingTrackInfo()
-        {
-            if(playingPath != null) {
-                TreeIter playingIter;
-                if(store.GetIter(out playingIter, playingPath))
-                    return IterTrackInfo(playingIter);
-            }
-            
-            return null;
-        }    
-        
-        private TreePath TrackInfoPath(TrackInfo ti)
-        {
-            TreeIter iter;
-            
-            for(int i = 0, n = Count(); i < n; i++) {
-                store.IterNthChild(out iter, i);
-                
-                if(IterTrackInfo(iter).Uid == ti.Uid) 
-                    return store.GetPath(iter);
-            }
-            
-            return null;
-        }
-            
-*/
-        /*private int FindIndex(TreePath a)
-        {
-            TreeIter iter;
-            TreePath b;
-            int i, n;
-    
-            for(i = 0, n = Count(); i < n; i++) {
-                store.IterNthChild(out iter, i);
-                b = store.GetPath(iter);
-                if(a.Compare(b) == 0) 
-                    return i;
-            }
-    
-            return -1;
-        }
-        
-        public void Advance()
-        {
-            ChangeDirection(true);    
-        }
-
-        public void Regress()
-        {
-            ChangeDirection(false);    
-        }
-
-        public void ContinuePlay()
-        {
-            Advance();
-        }
-        
-        private void ChangeDirection(bool forward)
-        {
-            TreePath path = playingPath;
-            TreeIter nextIter;
-            bool success = true;
-            int count, index;
-
-            if(shuffle) {
-                PlayRandomIter();
-                return;
-            }
-            
-            if(path == null)
-                return;
-            
-            count = Count();
-            index = FindIndex(path);
-            
-            if(count <= 0 || index < 0 || index >= count)
-                return;
-
-            if(forward && index < count - 1) 
-                path.Next();
-            else if(forward && repeat) {
-                if(store.IterNthChild(out nextIter, 0))
-                    PlayIter(nextIter);
-                //else {
-                //    playingPath = null;
-                //    QueueDraw();
-                //}
-                                    
-                return;
-            } else if(forward) {
-                //playingPath = null; 
-                //QueueDraw();
-                return;
-            }
-            
-            if(!forward && index > 0)
-                success = path.Prev();
-            else if(!forward)
-                return;
-            
-            if(path == null || !success)
-                return;
-            
-            if(!store.GetIter(out nextIter, path))
-                return;
-            
-            PlayIter(nextIter);
-        }
-        
-        private void ResetPlayingPath(TrackInfo cti)
-        {
-            TreeIter iter;
-            TrackInfo ti;
-            int i, n;
-    
-            for(i = 0, n = Count(); i < n; i++) {
-                store.IterNthChild(out iter, i);
-                ti = IterTrackInfo(iter);
-                if(ti.Uid == cti.Uid) {
-                    playingPath = store.GetPath(iter);
-                    QueueDraw();
-                    break;
-                }
-            }
-        }
-        
-        public int Count()
-        {
-            return store.IterNChildren();
-        }
-        
-        public void RemoveSelected()
-        {
-            TreePath [] paths = Selection.GetSelectedRows();
-            TreeIter [] iters = new TreeIter[paths.Length];
-            
-            for(int i = 0; i < iters.Length; i++) {
-                if(!store.GetIter(out iters[i], paths[i] as TreePath))
-                    return;
-            }
-        
-            for(int i = 0; i < iters.Length; i++) {
-                TreeIter playingIter, iter = (TreeIter)iters[i];
-                TrackInfo ti = null;
-                
-                if(playingPath != null && 
-                    store.GetIter(out playingIter, playingPath)) {
-                    if(playingPath.Compare(store.GetPath(iter)) == 0) 
-                        playingPath = null;
-                    else
-                        ti = IterTrackInfo(playingIter);
-                }
-                
-                try {
-                    totalDuration -= IterTrackInfo(iter).Duration;
-                } catch(Exception) {
-                }
-                
-                store.Remove(ref iter);
-                
-                if(Updated != null)
-                    Updated(this, new EventArgs());
-                    
-                if(ti != null)
-                    ResetPlayingPath(ti);
-            }
-        }
-        */
-        
-        
         public bool PlaySelected()
         {
             TreeIter selIter;
@@ -709,22 +511,7 @@ namespace Banshee
             model.PlayIter(selIter);
             return true;
         }
-        
-        public void AddSelectedToPlayList(string name)
-        {
-            Playlist pl = new Playlist(name);
-            pl.Load();
-        
-            foreach(TreePath p in Selection.GetSelectedRows()) {
-                TrackInfo ti = model.PathTrackInfo(p);
-                if(ti == null)
-                    continue;
-                pl.Append(ti);
-            }
-            
-            pl.Save();
-        }
-        
+       
         public TrackInfo SelectedTrackInfo {
             get {
                 TreePath [] paths = Selection.GetSelectedRows();
